==> apache-artemis-2.22.0-source-release.tar.gz: apache-artemis-2.22.0/artemis-core-client/src/main/java/org/apache/activemq/artemis/spi/core/remoting/ssl/OpenSSLContextFactoryProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.spi.core.remoting.ssl;

import java.util.ServiceLoader;

/**
 * Provider that loads all registered {@link OpenSSLContextFactory} services and returns the one with the highest priority.
 */
public class OpenSSLContextFactoryProvider {

   private static final OpenSSLContextFactory FACTORY;
   static {
      OpenSSLContextFactory factoryWithHighestPrio = null;
      for (OpenSSLContextFactory factory : ServiceLoader.load(OpenSSLContextFactory.class, OpenSSLContextFactoryProvider.class.getClassLoader())) {
         if (factoryWithHighestPrio == null || factory.getPriority() > factoryWithHighestPrio.getPriority()) {
            factoryWithHighestPrio = factory;
         }
      }

      FACTORY = factoryWithHighestPrio;
   }

   /**
    * @return the {@link OpenSSLContextFactory} with the higher priority.
    */
   public static OpenSSLContextFactory getOpenSSLContextFactory() {
      return FACTORY;
   }
}

==> apache-artemis-2.42.0-source-release.tar.gz: apache-artemis-2.42.0/artemis-core-client/src/main/java/org/apache/activemq/artemis/spi/core/remoting/ssl/OpenSSLContextFactoryProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.spi.core.remoting.ssl;

import java.util.ServiceLoader;

/**
 * Provider that loads all registered {@link OpenSSLContextFactory} services and returns the one with the highest
 * priority.
 */
public class OpenSSLContextFactoryProvider {

   private static final OpenSSLContextFactory FACTORY;
   static {
      OpenSSLContextFactory factoryWithHighestPrio = null;
      for (OpenSSLContextFactory factory : ServiceLoader.load(OpenSSLContextFactory.class, OpenSSLContextFactoryProvider.class.getClassLoader())) {
         if (factoryWithHighestPrio == null || factory.getPriority() > factoryWithHighestPrio.getPriority()) {
            factoryWithHighestPrio = factory;
         }
      }

      FACTORY = factoryWithHighestPrio;
   }

   /**
    * @return the {@link OpenSSLContextFactory} with the higher priority
    */
   public static OpenSSLContextFactory getOpenSSLContextFactory() {
      return FACTORY;
   }
}
